# WorkV30

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**created_date** | [**CreatedDateV30**](CreatedDateV30.md) |  | [optional] 
**last_modified_date** | [**LastModifiedDateV30**](LastModifiedDateV30.md) |  | [optional] 
**source** | [**SourceV30**](SourceV30.md) |  | [optional] 
**put_code** | **int** |  | [optional] 
**path** | **str** |  | [optional] 
**title** | [**WorkTitleV30**](WorkTitleV30.md) |  | [optional] 
**journal_title** | [**TitleV30**](TitleV30.md) |  | [optional] 
**short_description** | **str** |  | [optional] 
**citation** | [**Citation**](Citation.md) |  | [optional] 
**type** | **str** |  | [optional] 
**publication_date** | [**PublicationDateV30**](PublicationDateV30.md) |  | [optional] 
**external_ids** | [**ExternalIDsV30**](ExternalIDsV30.md) |  | [optional] 
**url** | [**UrlV30**](UrlV30.md) |  | [optional] 
**contributors** | [**WorkContributorsV30**](WorkContributorsV30.md) |  | [optional] 
**language_code** | **str** |  | [optional] 
**country** | [**CountryV30**](CountryV30.md) |  | [optional] 
**visibility** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

